summaryrefslogtreecommitdiffstats
path: root/src/main_dpdk.h
diff options
context:
space:
mode:
authorIdo Barnea <ibarnea@cisco.com>2016-03-15 18:36:04 +0200
committerIdo Barnea <ibarnea@cisco.com>2016-03-22 17:40:02 +0200
commitdd0507516960de491a3c697680d970f31661714b (patch)
treed39534d9d3118ba5a4602b7e5d435d89656d77cd /src/main_dpdk.h
parent582d3f74d66b81fbe798e54e75ade27561da58d8 (diff)
RX bytes reporting working
Diffstat (limited to 'src/main_dpdk.h')
-rw-r--r--src/main_dpdk.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/main_dpdk.h b/src/main_dpdk.h
index c5d2d4d7..ff1ea784 100644
--- a/src/main_dpdk.h
+++ b/src/main_dpdk.h
@@ -38,7 +38,8 @@ class CPhyEthIFStats {
uint64_t oerrors; /**< Total number of failed transmitted packets. */
uint64_t imcasts; /**< Total number of multicast received packets. */
uint64_t rx_nombuf; /**< Total number of RX mbuf allocation failures. */
- uint64_t m_rx_per_flow [MAX_FLOW_STATS]; // Per flow RX statistics
+ uint64_t m_rx_per_flow_pkts [MAX_FLOW_STATS]; // Per flow RX pkts
+ uint64_t m_rx_per_flow_bytes[MAX_FLOW_STATS]; // Per flow RX bytes
// Previous fdir stats values read from driver. Since on xl710 this is 32 bit, we save old value, to handle wrap around.
uint32_t m_fdir_prev_pkts [MAX_FLOW_STATS];
uint32_t m_fdir_prev_bytes [MAX_FLOW_STATS];
@@ -74,7 +75,7 @@ class CPhyEthIF {
void get_stats(CPhyEthIFStats *stats);
int dump_fdir_global_stats(FILE *fd);
int reset_hw_flow_stats();
- int get_flow_stats(uint64_t *rx_stats, tx_per_flow_t *tx_stats, int min, int max, bool reset);
+ int get_flow_stats(rx_per_flow_t *rx_stats, tx_per_flow_t *tx_stats, int min, int max, bool reset);
void get_stats_1g(CPhyEthIFStats *stats);
void rx_queue_setup(uint16_t rx_queue_id,
uint16_t nb_rx_desc,